@@ -33,12 +33,12 @@ class ChooseSerial : public GenericPage
 {
     Q_OBJECT
 public:
-    explicit ChooseSerial(QWidget *parent = 0);
-    ~ChooseSerial();
+    explicit ChooseSerial(QWidget *parent = nullptr);
+    ~ChooseSerial() override;
 
-    void setValues(const QVariantHash &args) Q_DECL_OVERRIDE;
-    QVariantHash values() const Q_DECL_OVERRIDE;
-    bool isValid() const Q_DECL_OVERRIDE;
+    void setValues(const QVariantHash &args) override;
+    QVariantHash values() const override;
+    bool isValid() const override;
 
 public slots:
     void load();
