@@ -29,8 +29,6 @@
 #include <QRegExpValidator>
 #include <QDebug>
 
-#include <KIconLoader>
-
 PageAddPrinter::PageAddPrinter(QWidget *parent) :
     GenericPage(parent),
     ui(new Ui::PageAddPrinter)
@@ -40,26 +38,21 @@ PageAddPrinter::PageAddPrinter(QWidget *parent) :
 
     // setup default options
     setWindowTitle(i18nc("@title:window", "Select a Printer to Add"));
-    // loads the standard key icon
-    QPixmap pixmap;
-    pixmap = KIconLoader::global()->loadIcon(QLatin1String("printer"),
-                                             KIconLoader::NoGroup,
-                                             KIconLoader::SizeEnormous, // a not so huge icon
-                                             KIconLoader::DefaultState);
-    QPixmap icon(pixmap);
-    QPainter painter(&icon);
 
-    pixmap = KIconLoader::global()->loadIcon(QLatin1String("dialog-information"),
-                                             KIconLoader::NoGroup,
-                                             KIconLoader::SizeLarge, // a not so huge icon
-                                             KIconLoader::DefaultState);
-    // the emblem icon to size 32
-    int overlaySize = KIconLoader::SizeLarge;
+    const int printerSize = 128;
+    const int overlaySize = 48;
+
+    QPixmap printerIcon = QIcon::fromTheme(QStringLiteral("printer")).pixmap(printerSize);
+    const QPixmap preferencesIcon = QIcon::fromTheme(QStringLiteral("dialog-information")).pixmap(overlaySize);
+
+    QPainter painter(&printerIcon);
+
     // bottom right corner
-    const QPoint startPoint = QPoint(KIconLoader::SizeEnormous - overlaySize - 2,
-                                     KIconLoader::SizeEnormous - overlaySize - 2);
-    painter.drawPixmap(startPoint, pixmap);
-    ui->printerL->setPixmap(icon);
+    const QPoint startPoint = QPoint(printerSize - overlaySize - 2,
+                                     printerSize - overlaySize - 2);
+    painter.drawPixmap(startPoint, preferencesIcon);
+
+    ui->printerL->setPixmap(printerIcon);
 
     // May contain any printable characters except "/", "#", and space
     QRegExp rx(QLatin1String("[^/#\\ ]*"));
