@@ -29,10 +29,12 @@
 
 void QmlPlugins::registerTypes(const char* uri)
 {
-    Q_ASSERT(uri == QLatin1String("org.kde.plasma.printmanager"));
+    Q_ASSERT(QLatin1String(uri) == QLatin1String("org.kde.plasma.printmanager"));
     qmlRegisterType<PrinterModel>(uri, 0, 2, "PrinterModel");
     qmlRegisterType<PrinterSortFilterModel>(uri, 0, 2, "PrinterSortFilterModel");
     qmlRegisterType<JobModel>(uri, 0, 2, "JobModel");
     qmlRegisterType<JobSortFilterModel>(uri, 0, 2, "JobSortFilterModel");
     qmlRegisterType<ProcessRunner>(uri, 0, 2, "ProcessRunner");
 }
+
+#include "moc_qmlplugins.cpp"
