@@ -31,13 +31,11 @@
 
 #include <KMessageBox>
 #include <KAboutData>
-#include <KToolInvocation>
-#include <KIconLoader>
+#include <KIO/CommandLauncherJob>
 
 #include <QIcon>
 #include <QMenu>
 #include <KCupsRequest.h>
-#include <KCupsServer.h>
 #include <NoSelectionRectDelegate.h>
 
 #include <cups/cups.h>
@@ -63,7 +61,7 @@ PrintKCM::PrintKCM(QWidget *parent, const QVariantList &args) :
 
     // The printer list needs to increase in width according to the icon sizes
     // default dialog icon size is 32, this times 6 is 192 which is roughly the original width
-    ui->printersTV->setMinimumWidth(IconSize(KIconLoader::Dialog) * 6);
+    ui->printersTV->setMinimumWidth(192);
 
     auto addMenu = new QMenu(this);
     addMenu->addAction(i18nc("@action:intoolbar","Add a Printer Class"),
@@ -251,14 +249,14 @@ void PrintKCM::update()
 
 void PrintKCM::on_addTB_clicked()
 {
-    KToolInvocation::kdeinitExec(QLatin1String("kde-add-printer"),
-    { QLatin1String("--add-printer") });
+    auto job = new KIO::CommandLauncherJob(QStringLiteral("kde-add-printer"), { QStringLiteral("--add-printer") });
+    job->start();
 }
 
 void PrintKCM::addClass()
 {
-    KToolInvocation::kdeinitExec(QLatin1String("kde-add-printer"),
-    { QLatin1String("--add-class") });
+    auto job = new KIO::CommandLauncherJob(QStringLiteral("kde-add-printer"), { QStringLiteral("--add-class") });
+    job->start();
 }
 
 void PrintKCM::on_removeTB_clicked()
