@@ -30,8 +30,8 @@
 #include <QMenu>
 #include <QProcess>
 
-#include <KIconLoader>
-#include <KToolInvocation>
+#include <KIO/CommandLauncherJob>
+
 #define PRINTER_ICON_SIZE 128
 
 Q_DECLARE_METATYPE(QList<int>)
@@ -44,20 +44,9 @@ PrinterDescription::PrinterDescription(QWidget *parent) :
     m_layoutEnd = ui->formLayout->count();
 
     // loads the standard key icon
-    m_printerIcon = KIconLoader::global()->loadIcon(QLatin1String("printer"),
-                    KIconLoader::NoGroup,
-                    PRINTER_ICON_SIZE, // a not so huge icon
-                    KIconLoader::DefaultState);
+    m_printerIcon = QIcon::fromTheme(QStringLiteral("printer")).pixmap(PRINTER_ICON_SIZE);
     ui->iconL->setPixmap(m_printerIcon);
 
-    m_pauseIcon = KIconLoader::global()->loadIcon(QLatin1String("media-playback-pause"),
-                  KIconLoader::NoGroup,
-                  KIconLoader::SizeMedium,
-                  KIconLoader::DefaultState,
-                  QStringList(),
-                  nullptr,
-                  true);
-
     auto menu = new QMenu(ui->maintenancePB);
     menu->addAction(ui->actionPrintTestPage);
     menu->addAction(ui->actionPrintSelfTestPage);
@@ -77,7 +66,8 @@ PrinterDescription::~PrinterDescription()
 
 void PrinterDescription::on_openQueuePB_clicked()
 {
-    KToolInvocation::kdeinitExec(QLatin1String("kde-print-queue"), { m_destName });
+    auto job = new KIO::CommandLauncherJob(QStringLiteral("kde-print-queue"), { m_destName });
+    job->start();
 }
 
 void PrinterDescription::on_defaultCB_clicked()
